@@ -5,14 +5,27 @@ import logging
 import zmq
 import shortuuid
 
-# TODO: Add documentation
-
 
 class dashConnection(threading.Thread):
     """Setups and manages a connection thread to the Dash Server."""
 
     def __on_connect(self, client, userdata, flags, rc):
-        logging.debug("rc: %s", str(rc))
+        if rc == 0:
+            self.connected = True
+            self.disconnect = False
+            if self.device_list:
+                for device in self.device_list:
+                    control_topic = "{}/{}/control".format(self.username, device.device_id)
+                    self.dash_c.subscribe(control_topic, 0)
+                    self.__send_dash_announce(device)
+            logging.debug("connected OK")
+        else:
+            logging.debug("Bad connection Returned code=%s", rc)
+
+    def __on_disconnect(self, client, userdata, rc):
+        logging.debug("disconnecting reason  " + str(rc))
+        self.connected = False
+        self.disconnect = True
 
     def __on_message(self, client, obj, msg):
         data = str(msg.payload, "utf-8").strip()
@@ -29,12 +42,26 @@ class dashConnection(threading.Thread):
         logging.debug(string)
 
     def add_device(self, device):
-        device.add_connection(self.connection_id)
-        control_topic = "{}/{}/control".format(self.username, device.device_id)
-        self.dash_c.subscribe(control_topic, 0)
-        device.send_dash_connect()
+        if device not in self.device_list:
+            self.device_list.append(device)
+            device.add_connection(self)
+            if self.connected:
+                control_topic = "{}/{}/control".format(self.username, device.device_id)
+                self.dash_c.subscribe(control_topic, 0)
+                self.__send_dash_announce(device)
 
-    def __init__(self, username, password, host='dash.dashio.io', port=8883, context=None):
+    def __send_dash_announce(self, device):
+        data_topic = "{}/{}/announce".format(self.username, device.device_id)
+        data = device.device_id_str + "\tWHO\t{}\t{}\n".format(device.device_type, device.device_name_cntrl.control_id)
+        self.dash_c.publish(data_topic, data)
+
+    def set_connection(self, username, password):
+        self.dash_c.disconnect()
+        self.username = username
+        self.dash_c.username_pw_set(username, password)
+        self.dash_c.connect(self.host, self.port)
+
+    def __init__(self, username="", password="", host='dash.dashio.io', port=8883, set_by_iotdashboard=False, context=None):
         """
         Arguments:
             host {str} -- The server name of the dash host.
@@ -46,19 +73,22 @@ class dashConnection(threading.Thread):
         threading.Thread.__init__(self, daemon=True)
 
         self.context = context or zmq.Context.instance()
-
+        self.connected = False
         self.connection_id = shortuuid.uuid()
         self.b_connection_id = self.connection_id.encode('utf-8')
-
+        self.device_list = []
         self.LWD = "OFFLINE"
         self.running = True
         self.username = username
         self.dash_c = mqtt.Client()
-
+        self.host = host
+        self.port = port
+        self.set_by_iotdashboard = set_by_iotdashboard
         # Assign event callbacks
         self.dash_c.on_message = self.__on_message
         self.dash_c.on_connect = self.__on_connect
-        self.dash_c.on_publish = self.__on_publish
+        self.dash_c.on_disconnect = self.__on_disconnect
+        # self.dash_c.on_publish = self.__on_publish
         self.dash_c.on_subscribe = self.__on_subscribe
 
         self.dash_c.tls_set(
@@ -74,8 +104,9 @@ class dashConnection(threading.Thread):
         self.dash_c.on_log = self.__on_log
         # self.dash_c.will_set(self.data_topic, self.LWD, qos=1, retain=False)
         # Connect
-        self.dash_c.username_pw_set(username, password)
-        self.dash_c.connect(host, port)
+        if username and password:
+            self.dash_c.username_pw_set(username, password)
+            self.dash_c.connect(host, port)
         # Start subscribe, with QoS level 0
         self.start()
 
@@ -110,18 +141,21 @@ class dashConnection(threading.Thread):
 
             if rx_zmq_sub in socks:
                 [address, id, data] = rx_zmq_sub.recv_multipart()
-                logging.debug("TX: %s", data.decode('utf-8').rstrip())
                 msg_l = data.split(b'\t')
-                device_id = msg_l[1].decode('utf-8').strip()
-                if address == b'ANNOUNCE':
-                    data_topic = "{}/{}/announce".format(self.username, device_id)
-                elif address == b'ALARM':
+                try:
+                    device_id = msg_l[1].decode('utf-8').strip()
+                except IndexError:
+                    continue
+                if address == b'ALARM':
                     data_topic = "{}/{}/alarm".format(self.username, device_id)
                 else:
                     data_topic = "{}/{}/data".format(self.username, device_id)
-                self.dash_c.publish(data_topic, data.decode('utf-8'))
+                if self.connected:
+                    logging.debug("DASH TX: %s", data.decode('utf-8').rstrip())
+                    self.dash_c.publish(data_topic, data.decode('utf-8'))
 
-        self.dash_c.publish(self.announce_topic, "disconnect")
+        if self.connected:
+            self.dash_c.publish(self.announce_topic, "disconnect")
         self.dash_c.loop_stop()
 
         self.tx_zmq_pub.close()
