@@ -1,11 +1,12 @@
 import logging
 import zmq
 import threading
+import json
 
 from .iotcontrol.name import Name
 from .iotcontrol.alarm import Alarm
 from .iotcontrol.page import Page
-
+from .iotcontrol.event import Event
 
 class dashDevice(threading.Thread):
 
@@ -25,6 +26,7 @@ class dashDevice(threading.Thread):
     def __on_command(self, data):
         data_array = data.split("\t")
         rx_device_id = data_array[0]
+        # logging.debug('Device RX: %s', rx_device_id)
         reply = ""
         if rx_device_id == "WHO":
             reply = self.device_id_str + "\tWHO\t{}\t{}\n".format(self.device_type, self.device_name_cntrl.control_id)
@@ -37,14 +39,21 @@ class dashDevice(threading.Thread):
         elif cntrl_type == "STATUS":
             reply = self.__make_status()
         elif cntrl_type == "CFG":
-            reply = self.__make_cfg()
+            reply = self.__make_cfg(data_array[2], data_array[3])
         elif cntrl_type == "NAME":
-            self.device_name_cntrl.message_rx_event(data_array[2:])
+            if self._set_name:
+                self.device_name_cntrl.message_rx_event(data_array[2:])
+        elif cntrl_type == "WIFI":
+            if self._set_wifi:
+                self.wifi_rx_event(data_array)
+        elif cntrl_type == "DASH":
+            if self._set_dash:
+                self.dash_rx_event(data_array)
         else:
             try:
                 key = cntrl_type + "_" + data_array[2]
             except IndexError:
-                return
+                return reply
             try:
                 self.control_dict[key].message_rx_event(data_array)
             except KeyError:
@@ -55,21 +64,15 @@ class dashDevice(threading.Thread):
         reply = ""
         for key in self.control_dict.keys():
             try:
-                status = self.control_dict[key].get_state()
-                if status:
-                    reply += self.device_id_str + self.__insert_device_id(self.control_dict[key].get_state())
+                reply += self.control_dict[key].get_state().format(device_id=self.device_id)
             except TypeError:
                 pass
         return reply
 
-    def __make_cfg(self):
-        reply = ""
-        if self.number_of_pages:
-            reply = self.device_id_str + '\tCFG\tDVCE\t{{"numPages": {}}}\n'.format(self.number_of_pages)
+    def __make_cfg(self, page_x, page_y):
+        reply = self.device_id_str + '\tCFG\tDVCE\t' + json.dumps(self._cfg) + "\n"
         for key in self.control_dict.keys():
-            reply += self.device_id_str + self.control_dict[key].get_cfg()
-        for key in self.alarm_dict.keys():
-            reply += self.alarm_dict[key].get_cfg()
+            reply += self.device_id_str + self.control_dict[key].get_cfg(page_x, page_y)
         return reply
 
     def send_popup_message(self, title, header, message):
@@ -104,16 +107,7 @@ class dashDevice(threading.Thread):
         logging.debug("ALARM: %s", payload)
         self.tx_zmq_pub.send_multipart([b"ALARM", b'0', payload.encode('utf-8')])
 
-    def send_dash_connect(self):
-        data = self.device_id_str + "\tWHO\t{}\t{}\n".format(self.device_type, self.device_name_cntrl.control_id)
-        self.tx_zmq_pub.send_multipart([b'ANNOUNCE', b'0', data.encode('utf-8')])
-
-    def __insert_device_id(self, data):
-        msg = data.rstrip()
-        reply = msg.replace("\n", "\n\t{}".format(self.device_id))
-        return reply + "\n"
-
-    def send_data(self, data):
+    def send_data(self, data: str):
         """Send data.
 
         Parameters
@@ -121,9 +115,9 @@ class dashDevice(threading.Thread):
         data : str
             Data to be sent
         """
-        msg = self.device_id_str + self.__insert_device_id(data)
+        reply_send = data.format(device_id=self.device_id)
         try:
-            self.tx_zmq_pub.send_multipart([b"ALL", b'0', msg.encode('utf-8')])
+            self.tx_zmq_pub.send_multipart([b"ALL", b'0', reply_send.encode('utf-8')])
         except zmq.error.ZMQError:
             pass
 
@@ -145,30 +139,105 @@ class dashDevice(threading.Thread):
             key = iot_control.msg_type + "_" + iot_control.control_id
             self.control_dict[key] = iot_control
 
-    def add_connection(self, connection_id):
-        tx_url_internal = "inproc://RX_{}".format(connection_id)
-        rx_url_internal = "inproc://TX_{}".format(connection_id)
+    def add_connection(self, device):
+        tx_url_internal = "inproc://RX_{}".format(device.connection_id)
+        rx_url_internal = "inproc://TX_{}".format(device.connection_id)
         self.tx_zmq_pub.connect(tx_url_internal)
         self.rx_zmq_sub.connect(rx_url_internal)
-        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, connection_id.encode('utf-8'))
+        self.rx_zmq_sub.setsockopt(zmq.SUBSCRIBE, device.connection_id.encode('utf-8'))
 
-    def __init__(self, device_type, device_id, device_name, context=None) -> None:
+    def __set_devicesetup(self):
+        device_setup = ""
+        if self._set_dash:
+            device_setup += "dashio"
+        if self._set_name:
+            if self._set_dash:
+                device_setup += ",name"
+            else:
+                device_setup += "name"
+        if self._set_wifi:
+            if self._set_dash or self._set_name:
+                device_setup += ",wifi"
+            else:
+                device_setup += "wifi"
+        self._cfg["deviceSetup"] = device_setup
+
+    def __init__(self,
+                 device_type,
+                 device_id,
+                 device_name,
+                 edit_lock=False,
+                 set_name=False,
+                 set_wifi=False,
+                 set_dash=False,
+                 context=None) -> None:
         threading.Thread.__init__(self, daemon=True)
 
         self.context = context or zmq.Context.instance()
+        self.wifi_rx_event = Event()
+        self.dash_rx_event = Event()
         self.device_type = device_type.strip()
         self.device_id = device_id.strip()
         self.device_name_cntrl = Name(device_name.strip())
         self.control_dict = {}
         self.alarm_dict = {}
-
+        self._cfg = {}
         self.add_control(self.device_name_cntrl)
         self.device_id_str = "\t{}".format(device_id)
         self.connect = self.device_id_str + "\tCONNECT\n"
         self.number_of_pages = 0
+
+        self.edit_lock = edit_lock
+        self._set_name = set_name
+        self._set_wifi = set_wifi
+        self._set_dash = set_dash
+        self.__set_devicesetup()
         self.running = True
         self.start()
 
+    @property
+    def edit_lock(self) -> bool:
+        return self._cfg["editLock"]
+
+    @edit_lock.setter
+    def edit_lock(self, val: bool):
+        self._cfg["editLock"] = val
+
+    @property
+    def number_of_pages(self) -> int:
+        return self._cfg["numPages"]
+
+    @number_of_pages.setter
+    def number_of_pages(self, val: int):
+        self._cfg["numPages"] = val
+
+    @property
+    def set_name(self) -> bool:
+        return self._set_name
+
+    @set_name.setter
+    def set_name(self, val: bool):
+        self._set_name = val
+        self.__set_devicesetup()
+
+    @property
+    def set_wifi(self) -> bool:
+        return self._set_wifi
+
+    @set_wifi.setter
+    def set_wifi(self, val: bool):
+        self._set_wifi = val
+        self.__set_devicesetup()
+
+    @property
+    def set_dash(self) -> bool:
+        return self._set_dash
+
+    @set_dash.setter
+    def set_dash(self, val: bool):
+        self._set_dash = val
+        self.__set_devicesetup()
+
     def close(self):
         self.running = False
 
