@@ -19,7 +19,6 @@ class ButtonGroup(Control):
     ):
         super().__init__("BTGP", control_id, control_position=control_position, title_position=title_position)
         self.title = title
-        self._state_str = "\t{}\t{}\t".format(self.msg_type, self.control_id)
         self.icon_name = icon
         self.text = text
         self.grid_view = grid_view
@@ -48,9 +47,9 @@ class ButtonGroup(Control):
         self._cfg["iconName"] = val.value
 
     @property
-    def text(self):
+    def text(self) -> str:
         return self._cfg["text"]
 
     @text.setter
-    def text(self, val):
+    def text(self, val: str):
         self._cfg["text"] = val
