@@ -9,30 +9,30 @@ class Dash(Control):
         self.message_rx_event += self.__set_dash
         self.username = username
         self.servername = servername
-        self.state_str = "\t{}\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self.username, self.servername)
+        self.state_str = self._state_str + "\t{}\t{}\n".format(self.username, self.servername)
 
     def __set_dash(self, msg):
         self.username = msg[3]
         self.servername = msg[4]
-        self.state_str = "\t{}\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self.username, self.servername)
+        self.state_str = self._state_str + "\t{}\t{}\n".format(self.username, self.servername)
 
     def set_mqtt(self, username, servername):
         self.username = username
         self.servername = servername
-        self.state_str = "\t{}\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self.username, self.servername)
+        self.state_str = self._state_str + "\t{}\t{}\n".format(self.username, self.servername)
 
     @property
-    def username(self):
+    def username(self) -> str:
         return self._cfg["userName"]
 
     @username.setter
-    def username(self, val):
+    def username(self, val: str):
         self._cfg["userName"] = val
 
     @property
-    def servername(self):
+    def servername(self) -> str:
         return self._cfg["hostURL"]
 
     @servername.setter
-    def servername(self, val):
+    def servername(self, val: str):
         self._cfg["hostURL"] = val
\ No newline at end of file
