@@ -98,9 +98,22 @@ class Keyboard(Enum):
     NONE = "NONE"
     ALL_CHARS = "ALL"
     NUMERIC = "NUM"
+    DATE = "DATE"
+    TIME = "TIME"
+    DATETIME = "DATETIME"
+    INTERVAL = "INTVL"
+    INT = "INT"
     HEX = "HEX"
 
 
+class TextFormat(Enum):
+    NONE = "NONE"
+    NUMBER = "NUM"
+    DATETIME = "DATETIME"
+    DATELONG = "DTLONG"
+    INTERVAL = "INTVL"
+
+
 class TextAlignment(Enum):
     LEFT = "left"
     CENTER = "center"
@@ -112,7 +125,7 @@ class SliderBarType(Enum):
     SOLID = "solid"
 
 
-class DialPosition(Enum):
+class DialNumberPosition(Enum):
     OFF = "off"
     LEFT = "left"
     RIGHT = "right"
