@@ -22,7 +22,7 @@ class Graph(Control):
     def get_state(self):
         state_str = ""
         for key in self.line_dict.keys():
-            state_str += self.get_state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._state_str + key + self.line_dict[key].get_line_data()
         return state_str
 
     def __init__(
@@ -54,7 +54,6 @@ class Graph(Control):
         self.y_axis_num_bars = y_axis_num_bars
 
         self.line_dict = {}
-        self.get_state_str = "\t{}\t{}\t".format(self.msg_type, self.control_id)
 
     def add_line(self, line_id, gline):
         self.line_dict[line_id] = gline
@@ -62,78 +61,78 @@ class Graph(Control):
     def send_graph(self):
         state_str = ""
         for key in self.line_dict.keys():
-            state_str += self.get_state_str + key + self.line_dict[key].get_line_data()
+            state_str += self._state_str + key + self.line_dict[key].get_line_data()
         self.state_str = state_str
 
     @property
-    def x_axis_label(self):
+    def x_axis_label(self) -> str:
         return self._cfg["xAxisLabel"]
 
     @x_axis_label.setter
-    def x_axis_label(self, val):
+    def x_axis_label(self, val: str):
         self._cfg["xAxisLabel"] = val
 
     @property
-    def x_axis_min(self):
+    def x_axis_min(self) -> float:
         return self._cfg["xAxisMin"]
 
     @x_axis_min.setter
-    def x_axis_min(self, val):
+    def x_axis_min(self, val: float):
         self._cfg["xAxisMin"] = val
 
     @property
-    def x_axis_max(self):
+    def x_axis_max(self) -> float:
         return self._cfg["xAxisMax"]
 
     @x_axis_max.setter
-    def x_axis_max(self, val):
+    def x_axis_max(self, val: float):
         self._cfg["xAxisMax"] = val
 
     @property
-    def x_axis_num_bars(self):
+    def x_axis_num_bars(self) -> int:
         return self._cfg["xAxisNumBars"]
 
     @x_axis_num_bars.setter
-    def x_axis_num_bars(self, val):
+    def x_axis_num_bars(self, val: int):
         self._cfg["xAxisNumBars"] = val
 
     @property
-    def x_axis_labels_style(self):
+    def x_axis_labels_style(self) -> GraphXAxisLabelsStyle:
         return self._x_axis_labels_style
 
     @x_axis_labels_style.setter
-    def x_axis_labels_style(self, val):
+    def x_axis_labels_style(self, val: GraphXAxisLabelsStyle):
         self._x_axis_labels_style = val
         self._cfg["xAxisLabelsStyle"] = val.value
 
     @property
-    def y_axis_label(self):
+    def y_axis_label(self) -> str:
         return self._cfg["yAxisLabel"]
 
     @y_axis_label.setter
-    def y_axis_label(self, val):
+    def y_axis_label(self, val: str):
         self._cfg["yAxisLabel"] = val
 
     @property
-    def y_axis_min(self):
+    def y_axis_min(self) -> float:
         return self._cfg["yAxisMin"]
 
     @y_axis_min.setter
-    def y_axis_min(self, val):
+    def y_axis_min(self, val: float):
         self._cfg["yAxisMin"] = val
 
     @property
-    def y_axis_max(self):
+    def y_axis_max(self) -> float:
         return self._cfg["yAxisMax"]
 
     @y_axis_max.setter
-    def y_axis_max(self, val):
+    def y_axis_max(self, val: float):
         self._cfg["yAxisMax"] = val
 
     @property
-    def y_axis_num_bars(self):
+    def y_axis_num_bars(self) -> int:
         return self._cfg["yAxisNumBars"]
 
     @y_axis_num_bars.setter
-    def y_axis_num_bars(self, val):
+    def y_axis_num_bars(self, val: int):
         self._cfg["yAxisNumBars"] = val
