@@ -19,7 +19,6 @@ class Menu(Control):
                  title_position=TitlePosition.BOTTOM):
         super().__init__("MENU", control_id, control_position=control_position, title_position=title_position)
         self.title = title
-        self._state_str = "\t{}\t{}\t".format(self.msg_type, self.control_id)
         self.icon_name = icon
         self.text = text
 
@@ -44,9 +43,9 @@ class Menu(Control):
         self._cfg["iconName"] = val.value
 
     @property
-    def text(self):
+    def text(self) -> str:
         return self._cfg["text"]
 
     @text.setter
-    def text(self, val):
+    def text(self, val: str):
         self._cfg["text"] = val
