@@ -10,8 +10,8 @@ class Name(Control):
 
     def __set_device_name(self, msg):
         self.control_id = msg[3]
-        self.state_str = "\t{}\t{}\n".format(self.msg_type, msg[0])
+        self.state_str = "\t{{device_id}}\t{}\t{}\n".format(self.msg_type, msg[0])
 
-    def set_device_name(self, device_name):
+    def set_device_name(self, device_name: str):
         self.control_id = device_name
-        self.state_str = "\t{}\t{}\n".format(self.msg_type, device_name)
+        self.state_str = "\t{{device_id}}\t{}\t{}\n".format(self.msg_type, device_name)
