@@ -11,7 +11,7 @@ class Selector(Control):
         self._cfg["selection"] = self.selection_list
 
     def get_state(self):
-        _state_str = "\t{}\t{}\t{}\t".format(self.msg_type, self.control_id, self.position)
+        _state_str = self._state_str + "{}\t".format(self.position)
         _state_str += "\t".join(map(str, self.selection_list))
         _state_str += "\n"
         return _state_str
@@ -22,20 +22,20 @@ class Selector(Control):
     def set_selected(self, selected_text):
         if selected_text in self.selection_list:
             self._position = self.selection_list.index(selected_text)
-            slctr_str = "\t{}\t{}\t{}\t".format(self.msg_type, self.control_id, self._position)
+            slctr_str = self._state_str + "{}\t".format(self._position)
             slctr_str += "\t".join(map(str, self.selection_list))
             slctr_str += "\n"
             self.state_str = slctr_str
 
     @property
-    def position(self):
+    def position(self) -> int:
         return self._position
 
     @position.setter
-    def position(self, val):
+    def position(self, val: int):
         try:
             _ = self.selection_list[val]
             self._position = val
-            self.state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self._position)
+            self.state_str = self._state_str + "{}\n".format(self._position)
         except IndexError:
             pass
