@@ -33,44 +33,42 @@ class SliderDoubleBar(SliderSingleBar):
                          control_position)
 
         self._bar2_value = 0.0
-        self._bar_state_str = "\t{}\t{}\t{:.2f}\t{:.2f}\n".format(
-            self._control_id_bar, self.control_id, self._bar1_value, self._bar2_value
+        self._bar_state_str = self._state_str + "{:.2f}\t{:.2f}\n".format(self._bar1_value, self._bar2_value
         )
-        self._state_str = self._slider_state_str + self._bar_state_str
+        self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
     @property
-    def bar1_value(self):
+    def bar1_value(self) -> float:
         return self._bar1_value
 
     @bar1_value.setter
-    def bar1_value(self, val):
+    def bar1_value(self, val: float):
         self._bar1_value = val
-        self._bar_state_str = "\t{}\t{}\t{:.2f}\t{:.2f}\n".format(
+        self._bar_state_str = self._state_str + "{:.2f}\t{:.2f}\n".format(
             self._control_id_bar, self.control_id, val, self._bar2_value
         )
         self.message_tx_event(self._bar_state_str)
-        self._state_str = self._slider_state_str + self._bar_state_str
+        self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
     @property
-    def bar2_value(self):
+    def bar2_value(self) -> float:
         return self._bar2_value
 
     @bar2_value.setter
-    def bar2_value(self, val):
+    def bar2_value(self, val: float):
         self._bar2_value = val
-        self._bar_state_str = "\t{}\t{}\t{:.2f}\t{:.2f}\n".format(
-            self._control_id_bar, self.control_id, self._bar1_value, val
+        self._bar_state_str = self._state_str + "{:.2f}\t{:.2f}\n".format(self._bar1_value, val
         )
         self.message_tx_event(self._bar_state_str)
-        self._state_str = self._slider_state_str + self._bar_state_str
+        self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
 
     @property
-    def slider_value(self):
+    def slider_value(self) -> float:
         return self._slider_value
 
     @slider_value.setter
-    def slider_value(self, val):
+    def slider_value(self, val: float):
         self._slider_value = val
-        self._slider_state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self._slider_value)
+        self._slider_state_str = self._state_str + "{}\n".format(self._slider_value)
         self.message_tx_event(self._slider_state_str)
-        self._state_str = self._slider_state_str + self._bar_state_str
+        self._bar_slider_state_str = self._slider_state_str + self._bar_state_str
