@@ -1,4 +1,4 @@
-from .enums import TextAlignment, Precision, Keyboard, TitlePosition
+from .enums import TextAlignment, Precision, Keyboard, TitlePosition, TextFormat
 from .control import Control
 
 
@@ -10,6 +10,7 @@ class TextBox(Control):
         title_position=TitlePosition.BOTTOM,
         text="",
         text_align=TextAlignment.LEFT,
+        text_format=TextFormat.NONE,
         units="",
         precision=Precision.OFF,
         keyboard_type=Keyboard.ALL_CHARS,
@@ -22,9 +23,12 @@ class TextBox(Control):
         self.text_align = text_align
         self.units = units
         self.precision = precision
+        self.text_format = text_format
         self.keyboard_type = keyboard_type
         self.close_keyboard_on_send = close_keyboard_on_send
-        self._state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self.text)
+
+    def get_state(self):
+        return self._state_str + "{}\n".format(self.text)
 
     @property
     def text(self):
@@ -33,7 +37,7 @@ class TextBox(Control):
     @text.setter
     def text(self, val):
         self._text = val
-        self.state_str = "\t{}\t{}\t{}\n".format(self.msg_type, self.control_id, self.text)
+        self.state_str = self._state_str + "{}\n".format(self.text)
 
     @property
     def text_align(self) -> TextAlignment:
@@ -45,15 +49,24 @@ class TextBox(Control):
         self._cfg["textAlign"] = val.value
 
     @property
-    def units(self):
+    def text_format(self) -> TextFormat:
+        return self._text_format
+
+    @text_format.setter
+    def text_format(self, val: TextFormat):
+        self._text_format = val
+        self._cfg["format"] = val.value
+
+    @property
+    def units(self) -> str:
         return self._cfg["units"]
 
     @units.setter
-    def units(self, val):
+    def units(self, val: str):
         self._cfg["units"] = val
 
     @property
-    def precision(self):
+    def precision(self) -> Precision:
         return self._precision
 
     @precision.setter
